/***************************************************************************
                          passconf.cpp  -  description
                             -------------------
    begin                : Wed May 3 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@kpage.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/***************************************************************************
                          passconf.cpp  -  description
                             -------------------
    begin                : Sun Jan 23 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "passconf.h"

PassConf::PassConf(QWidget *parent, const char *name )
		: QFrame(parent,name)
{
	QFont fnt("helvetica", 12,QFont::Bold);	
	fnt.setUnderline(true);

	QLabel *httpLab = new QLabel(i18n("HTTP-Logins:"), this);
	httpLab->setGeometry(10,10,130,20);
	httpLab->setFont(fnt);

	fnt.setUnderline(false);

	QLabel *httpusrLab = new QLabel(i18n("UserName :"), this);
	httpusrLab->setGeometry(10,40,100,20);
	httpusrLab->setFont(fnt);

	QLabel *httppassLab = new QLabel(i18n("Password :"), this);
	httppassLab->setGeometry(10,60,100,20);
	httppassLab->setFont(fnt);

	httpusrLine = new QLineEdit(this);
	httpusrLine->setGeometry(110,40,200,20);
	
	httppassLine = new QLineEdit(this);
	httppassLine->setGeometry(110,60,200,20);
	httppassLine->setEchoMode(QLineEdit::Password);

	fnt.setUnderline(true);

	QLabel *ftpLab = new QLabel(i18n("FTP-Logins:"), this);
	ftpLab->setGeometry(10,110,130,20);
	ftpLab->setFont(fnt);

	fnt.setUnderline(false);

	QLabel *ftpusrLab = new QLabel(i18n("UserName :"), this);
	ftpusrLab->setGeometry(10,140,100,20);
	ftpusrLab->setFont(fnt);

	QLabel *ftppassLab = new QLabel(i18n("Password :"), this);
	ftppassLab->setGeometry(10,160,100,20);
	ftppassLab->setFont(fnt);

	ftpusrLine = new QLineEdit(this);
	ftpusrLine->setGeometry(110,140,200,20);
	ftpusrLine->setText("anonymous");
	ftpusrLine->setEnabled(false);

	ftppassLine = new QLineEdit(this);
	ftppassLine->setGeometry(110,160,200,20);

	fnt.setUnderline(true);

	httploginBox = new QCheckBox(i18n("Use HTTP-Username and Password"), this);
	httploginBox->setGeometry(320,40,230,20);
	
	ftpanonBox = new QCheckBox(i18n("Use anonymous-Login on FTP"), this);
	ftpanonBox->setGeometry(320,140,200,20);
	ftpanonBox->setChecked(true);
}

PassConf::~PassConf()
{
}

