/***************************************************************************
                          audiosel.cpp  -  description
                             -------------------
    begin                : Tue May 2 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@kpage.de
 ***************************************************************************/
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "audiosel.h"

AudioSel::AudioSel(QWidget *parent, const char *name )
		: QFrame(parent,name)
{
	 wavBox = new QCheckBox(".wav", this);
	 wavBox->setGeometry(15,25,70,15);
	 wavBox->setBackgroundColor(white);

	 midBox = new QCheckBox(".mid", this);
	 midBox->setGeometry(15,40,70,15);
	 midBox->setBackgroundColor(white);

	 mp2Box = new QCheckBox(".mp2", this);
	 mp2Box->setGeometry(15,55,70,15);
	 mp2Box->setBackgroundColor(white);

	 mp3Box = new QCheckBox(".mp3", this);
	 mp3Box->setGeometry(15,70,70,15);
	 mp3Box->setBackgroundColor(white);

	 sndBox = new QCheckBox(".snd", this);
	 sndBox->setGeometry(15,85,70,15);
	 sndBox->setBackgroundColor(white);

	 aiffBox = new QCheckBox(".aiff", this);
	 aiffBox->setGeometry(15,100,70,15);
	 aiffBox->setBackgroundColor(white);

	 ramBox = new QCheckBox(".ram", this);
	 ramBox->setGeometry(15,115,70,15);
	 ramBox->setBackgroundColor(white);
}
AudioSel::~AudioSel()
{
}

void AudioSel::showItems()
{
	wavBox->show();
	midBox->show();
	mp3Box->show();
	sndBox->show();
	mp2Box->show();
	aiffBox->show();
	ramBox->show();
}

void AudioSel::hideItems()
{
	wavBox->hide();
	midBox->hide();
	mp3Box->hide();
	sndBox->hide();
	mp2Box->hide();
	aiffBox->hide();
	ramBox->hide();
}

