/***************************************************************************
                          wizpage4.h  -  description
                             -------------------
    begin                : Wed Feb 9 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef WIZPAGE4_H
#define WIZPAGE4_H

#include <klocale.h>

#include <qwidget.h>
#include <qframe.h>
#include <qlabel.h>
#include <qspinbox.h>
#include <qcheckbox.h>

/**
  *@author Frank von Daak
  */

class WizPage4 : public QFrame  {
   Q_OBJECT
public: 
	WizPage4(QWidget *parent=0, const char *name=0);
	~WizPage4();

	QSpinBox *levBox, *quotaBox;
	QCheckBox *quotaBut, *levBut;

private slots:
	void enableQuota();
	void enableRecursive();
};

#endif

