/***************************************************************************
                          videosel.h  -  description
                             -------------------
    begin                : Fri Jan 21 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef VIDEOSEL_H
#define VIDEOSEL_H

#include <qwidget.h>
#include <qframe.h>
#include <qcheckbox.h>

/**
  *@author Frank von Daak
  */

class VideoSel : public QFrame  {
   Q_OBJECT
public: 
	VideoSel(QWidget *parent=0, const char *name=0);
	~VideoSel();

	QCheckBox *movBox, *mpegBox, *mpgBox, *rmBox, *aviBox, *qtBox;

	void hideItems();
	void showItems();
};

#endif

