/***************************************************************************
                          kscheduleicon.h  -  description
                             -------------------
    begin                : Sat Mar 18 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSCHEDULEICON_H
#define KSCHEDULEICON_H

#include <klocale.h>
#include <kwin.h>
#include <kpopupmenu.h>
#include <ksystemtray.h>

#include <qwidget.h>
#include <qpainter.h>

/**
  *@author Frank von Daak
  */

class KScheduleIcon : public KSystemTray  {
   Q_OBJECT
public: 
	KScheduleIcon(QWidget *parent=0, const char *name=0);
	~KScheduleIcon();
	
	KPopupMenu *schedPop;
	int menupunkt[5];

	void setActive(bool);

private:
	
	bool st;
	QPainter *p;
	void mousePressEvent(QMouseEvent *);
	void paintEvent(QPaintEvent *);
};

#endif

