/***************************************************************************
                          imagesel.cpp  -  description
                             -------------------
    begin                : Tue May 2 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@kpage.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "imagesel.h"

ImageSel::ImageSel(QWidget *parent, const char *name )
		: QFrame(parent,name)
{
	 jpgBox = new QCheckBox(".jpg", this);
	 jpgBox->setGeometry(15,25,70,15);
	 jpgBox->setBackgroundColor(white);

	 jpegBox = new QCheckBox(".jpeg", this);
	 jpegBox->setGeometry(15,40,70,15);
	 jpegBox->setBackgroundColor(white);

	 gifBox = new QCheckBox(".gif", this);
	 gifBox->setGeometry(15,55,70,15);
	 gifBox->setBackgroundColor(white);

	 bmpBox = new QCheckBox(".bmp", this);
	 bmpBox->setGeometry(15,70,70,15);
	 bmpBox->setBackgroundColor(white);

	 pngBox = new QCheckBox(".png", this);
	 pngBox->setGeometry(15,85,70,15);
	 pngBox->setBackgroundColor(white);

	 xpmBox = new QCheckBox(".xpm", this);
	 xpmBox->setGeometry(15,100,70,15);
	 xpmBox->setBackgroundColor(white);

	 pnmBox = new QCheckBox(".pnm", this);
	 pnmBox->setGeometry(15,115,70,15);
	 pnmBox->setBackgroundColor(white);
}

ImageSel::~ImageSel()
{
}

void ImageSel::showItems()
{
	jpgBox->show();
	jpegBox->show();
	gifBox->show();
	bmpBox->show();
	pngBox->show();
	xpmBox->show();
	pnmBox->show();
}

void ImageSel::hideItems()
{
	 jpgBox->hide();
	 xpmBox->hide();
	 pngBox->hide();
	 bmpBox->hide();
	 jpegBox->hide();
	 gifBox->hide();
	 pnmBox->hide();
}

