/***************************************************************************
                          wizpage3.h  -  description
                             -------------------
    begin                : Tue Feb 8 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef WIZPAGE3_H
#define WIZPAGE3_H

#include <klocale.h>

#include <qwidget.h>
#include <qframe.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qcombobox.h>
#include <qcheckbox.h>

#include "../mypushbutton.h"
#include "../listenterdialog.h"
#include "../mylineedit.h"

/**
  *@author Frank von Daak
  */

class WizPage3 : public QFrame  {
   Q_OBJECT
public: 
	WizPage3(QWidget *parent=0, const char *name=0);
	~WizPage3();

	QFrame *mirFrame, *fileFrame, *listFrame;
	QComboBox *protBox[2];
	QLineEdit *passLine[2], *userLine[2];
	MyLineEdit *urlLine[3], *fileLine[2];
	QCheckBox *loginBut[2], *anonBut[2];
	MyPushButton *sitelistBut;
	bool hasSiteList;
	ListEnterDialog *listWidg;
	
private:
	QString sitebak[200];
	bool protbak[200], anonbak[200];
	int	addNumBak;

	void mirrorSite();
	void singleFile();
	void siteList();

private slots:
	void enableLogin();
	void setAnon();
	void setAnon(int);
	void openSiteList();
	void backupList();
	void listApplyed();
	void listCanceled();
	void changeDropProt(QString);

signals:
	void listCompleted();
};

#endif

