/***************************************************************************
                          outputwidget.h  -  description
                             -------------------
    begin                : Tue Jan 25 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef OUTPUTWIDGET_H
#define OUTPUTWIDGET_H

#include <klocale.h>

#include <qdialog.h>
#include <qmultilinedit.h>
#include <qframe.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <qlabel.h>
#include <qstring.h>
#include <qpixmap.h>

/**
  *@author Frank von Daak
  */

class OutputWidget : public QDialog  {

public:
	OutputWidget(QWidget * parent=0, const char * name=0, bool modal=FALSE, WFlags f=0);
	~OutputWidget();

	QMultiLineEdit *outScreen;
	QPushButton *outDismiss, *outCancel;
	QCheckBox *noScroll;
	QString pixStr;
	QLabel *statPixLab;
	QPixmap runPix[12], stopPix;
	int tmr;
	bool dec;
	void timerEvent (QTimerEvent *);
	void getSchedInfo(bool);

private:
	bool scheduling;
	void closeEvent(QCloseEvent *);
};

#endif

