/***************************************************************************
                          proxyconf.h  -  description
                             -------------------
    begin                : Tue Mar 14 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PROXYCONF_H
#define PROXYCONF_H

#include <klocale.h>

#include <qwidget.h>
#include <qframe.h>
#include <qlabel.h>
#include <qfont.h>
#include <qlineedit.h>
#include <qcheckbox.h>
/**
  *@author Frank von Daak
  */

class ProxyConf : public QFrame  {
   Q_OBJECT
public: 
	ProxyConf(QWidget *parent=0, const char *name=0);
	~ProxyConf();

	QLineEdit *httpProxyusrLine, *httpProxypassLine, *httpProxyAdressLine,
			  *httpProxyPortLine;
	QCheckBox *httpProxyBox, *httpProxyloginBox;
	QLineEdit *ftpProxyAdressLine, *ftpProxyPortLine;
	QCheckBox *ftpProxyBox;
	QLabel *httpProxyusrLab, *httpProxypassLab;

public slots:
	void getHttpProxyLogin();
	void enableHttpProxy();

	void enableFtpProxy();
};

#endif

