/***************************************************************************
                          textsel.cpp  -  description
                             -------------------
    begin                : Tue May 2 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@kpage.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/***************************************************************************
                          textsel.cpp  -  description
                             -------------------
    begin                : Fri Jan 21 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "textsel.h"

TextSel::TextSel(QWidget *parent, const char *name )
		: QFrame(parent,name)
{
	 txtBox = new QCheckBox(".txt", this);
	 txtBox->setGeometry(15,25,70,15);
	 txtBox->setBackgroundColor(white);
	
	 docBox = new QCheckBox(".doc", this);
	 docBox->setGeometry(15,40,70,15);
	 docBox->setBackgroundColor(white);
	
	 htmlBox = new QCheckBox(".html", this);
	 htmlBox->setGeometry(15,55,70,15);
	 htmlBox->setBackgroundColor(white);
	
	 htmBox = new QCheckBox(".htm", this);
	 htmBox->setGeometry(15,70,70,15);
	 htmBox->setBackgroundColor(white);
	
	 shtmlBox = new QCheckBox(".shtml",this);
	 shtmlBox->setGeometry(15,85,70,15);
	 shtmlBox->setBackgroundColor(white);

	 aspBox = new QCheckBox(".asp",this);
	 aspBox->setGeometry(15,100,70,15);
	 aspBox->setBackgroundColor(white);

	 pdfBox = new QCheckBox(".pdf",this);
	 pdfBox->setGeometry(15,115,70,15);
	 pdfBox->setBackgroundColor(white);
}

TextSel::~TextSel()
{
}

void TextSel::showItems()
{
	txtBox->show();
	docBox->show();
	aspBox->show();
	htmlBox->show();
	htmBox->show();
	shtmlBox->show();
	pdfBox->show();
}

void TextSel::hideItems()
{
	txtBox->hide();
	docBox->hide();
	aspBox->hide();
	htmlBox->hide();
	htmBox->hide();
	shtmlBox->hide();
	pdfBox->hide();
}

