/***************************************************************************
                          fileconf.h  -  description
                             -------------------
    begin                : Sun Jan 23 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef FILECONF_H
#define FILECONF_H

#include <klocale.h>

#include <qwidget.h>
#include <qframe.h>
#include <qcheckbox.h>
#include <qbuttongroup.h>
#include <qfont.h>

#include "imagesel.h"
#include "textsel.h"
#include "audiosel.h"
#include "videosel.h"
#include "othersel.h"

/**
  *@author Frank von Daak
  */

class FileConf : public QFrame  {
   Q_OBJECT
public: 
	FileConf(QWidget *parent=0, const char *name=0);
	~FileConf();

  	  QCheckBox *getBut, *rejBut;
  	  ImageSel *imgFrame;
  	  TextSel *txtFrame;
  	  AudioSel *audFrame;
  	  VideoSel *vidFrame;
  	  OtherSel *othFrame;

  	  QString whatToGet();

private slots:
	void checkGetRejBut();
};

#endif

