/***************************************************************************
                          mydialog.h  -  description
                             -------------------
    begin                : Mon Feb 7 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MYDIALOG_H
#define MYDIALOG_H

#include <klocale.h>
#include <kapp.h>

#include <qwidget.h>
#include <qdialog.h>
#include <qlabel.h>
#include <qradiobutton.h>
#include <qcheckbox.h>
#include <qfont.h>
#include <qtooltip.h>

#include "mypushbutton.h"

/**
  *@author Frank von Daak
  */

class MyDialog : public QDialog  {
   Q_OBJECT
public:
	MyDialog(QWidget *parent=0, const char *name=0, bool modal=false, WFlags f=0);
	~MyDialog();
	
	QCheckBox *showAgain;
	QRadioButton *yesBut, *noBut;
	MyPushButton *closeBut;

private:
	void closeEvent(QCloseEvent *);
};

#endif

