/***************************************************************************
                          wizpage2.h  -  description
                             -------------------
    begin                : Mon Feb 7 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef WIZPAGE2_H
#define WIZPAGE2_H

#include <klocale.h>

#include <qwidget.h>
#include <qtooltip.h>
#include <qframe.h>
#include <qlabel.h>
#include <qcombobox.h>
#include <qlineedit.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>

/**
  *@author Frank von Daak
  */

class WizPage2 : public QFrame  {
   Q_OBJECT
public: 
	WizPage2(QWidget *parent=0, const char *name=0);
	~WizPage2();

	QComboBox *agentCombo;
	QLineEdit *agentLine;
	QRadioButton *mirrorBut, *singleBut, *moresitesBut;

private:
	QButtonGroup *butGroup;

//private slots:
//	void enableAgentLine(int);
};

#endif

