/***************************************************************************
                          othersel.h  -  description
                             -------------------
    begin                : Fri Jan 21 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef OTHERSEL_H
#define OTHERSEL_H

#include <klocale.h>
#include <qwidget.h>
#include <qframe.h>
#include <qcheckbox.h>
#include <qlineedit.h>
#include <qstring.h>
#include <qpopupmenu.h>
#include <qlabel.h>
#include <qfont.h>

/**
  *@author Frank von Daak
  */

class OtherSel : public QFrame  {
   Q_OBJECT
public: 
	OtherSel(QWidget *parent=0, const char *name=0);
	~OtherSel();

	QCheckBox *zipBox, *gzBox, *tarBox, *rarBox, *aceBox,
			  *bz2Box, *debBox, *exeBox, *rpmBox;
	QCheckBox *newftBox[25];
	QLineEdit *newftLine[25];
	int numFt, ftX, ftY, oldnumFt;
	QString newfileStr;
	QLabel *addLab;	
	void hideItems();
	void showItems();

private slots:
	void addNewFileType();
	void checkNewFileType(const QString&);
	void takeNewFileType();
};

#endif

