/***************************************************************************
                          statusdialog.h  -  description
                             -------------------
    begin                : Sat Mar 25 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef STATUSDIALOG_H
#define STATUSDIALOG_H

#include <klocale.h>

#include <qwidget.h>
#include <qdialog.h>
#include <qlabel.h>
#include <qpushbutton.h>

/**
  *@author Frank von Daak
  */

class StatusDialog : public QDialog  {
   Q_OBJECT
public: 
	StatusDialog(QWidget *parent=0, const char *name=0, bool modal=false, WFlags f=0);
	~StatusDialog();

	void getInfo(QString, QString, QString, QString);
	
private slots:
	void closeIt();

private:
	QPushButton *okBut;
	QLabel *stateIsLab, *dateIsLab, *timeIsLab, *nextIsLab;
};

#endif

