/***************************************************************************
                          textsel.h  -  description
                             -------------------
    begin                : Fri Jan 21 2000
    copyright            : (C) 2000 by Frank von Daak
    email                : frank.fun@skydsl.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TEXTSEL_H
#define TEXTSEL_H

#include <qwidget.h>
#include <qframe.h>
#include <qcheckbox.h>
#include <qlabel.h>

/**
  *@author Frank von Daak
  */

class TextSel : public QFrame  {
   Q_OBJECT
public: 
	TextSel(QWidget *parent=0, const char *name=0);
	~TextSel();
	
	QCheckBox *txtBox, *docBox, *htmlBox, *htmBox, *aspBox, *shtmlBox,
			  *pdfBox;

	void showItems();
	void hideItems();
};

#endif

